@@ -8,14 +8,23 @@ class WalletRESTException(exceptions.BackendException, exceptions.WalletExceptio
 
 
 class BadRequest(WalletRESTException):
+    """Raised when the underlying REST API returns HTTP code 400."""
+
     pass
 
 
 class NotFound(WalletRESTException):
+    """Raised when the underlying REST API returns HTTP code 404."""
+
     pass
 
 
 class RESTServerError(WalletRESTException):
+    """
+    Raised when the underlying REST API returns HTTP code 403 or 500 and the error cannot be
+    handled.
+    """
+
     pass
 
 
